==> piwik-2.15.0.tgz: piwik/plugins/CoreHome/Columns/VisitorDaysSinceOrder.php <==
<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */
namespace Piwik\Plugins\CoreHome\Columns;

use Piwik\Plugin\Dimension\VisitDimension;
use Piwik\Plugins\CoreHome\Segment;
use Piwik\Tracker\Action;
use Piwik\Tracker\Request;
use Piwik\Tracker\Visitor;

class VisitorDaysSinceOrder extends VisitDimension
{
    protected $columnName = 'visitor_days_since_order';
    protected $columnType = 'SMALLINT(5) UNSIGNED NOT NULL';

    protected function configureSegments()
    {
        $segment = new Segment();
        $segment->setSegment('daysSinceLastEcommerceOrder');
        $segment->setName('General_DaysSinceLastEcommerceOrder');
        $segment->setType(Segment::TYPE_METRIC);

        $this->addSegment($segment);
    }

    /**
     * @param Request $request
     * @param Visitor $visitor
     * @param Action|null $action
     * @return mixed
     */
    public function onNewVisit(Request $request, Visitor $visitor, $action)
    {
        $daysSinceLastOrder = $request->getDaysSinceLastOrder();

        if ($daysSinceLastOrder === false) {
            $daysSinceLastOrder = 0;
        }

        return $daysSinceLastOrder;
    }

    /**
     * @param Request $request
     * @param Visitor $visitor
     * @param Action|null $action
     * @return mixed
     */
    public function onAnyGoalConversion(Request $request, Visitor $visitor, $action)
    {
        return $visitor->getVisitorColumn($this->columnName);
    }
}

==> piwik-3.0.3.tgz: piwik/plugins/CoreHome/Columns/VisitorDaysSinceOrder.php <==
<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */
namespace Piwik\Plugins\CoreHome\Columns;

use Piwik\Plugin\Dimension\VisitDimension;
use Piwik\Plugins\CoreHome\Segment;
use Piwik\Tracker\Action;
use Piwik\Tracker\Request;
use Piwik\Tracker\Visitor;

class VisitorDaysSinceOrder extends VisitDimension
{
    protected $columnName = 'visitor_days_since_order';
    protected $columnType = 'SMALLINT(5) UNSIGNED NULL';

    protected function configureSegments()
    {
        $segment = new Segment();
        $segment->setSegment('daysSinceLastEcommerceOrder');
        $segment->setName('General_DaysSinceLastEcommerceOrder');
        $segment->setType(Segment::TYPE_METRIC);

        $this->addSegment($segment);
    }

    /**
     * @param Request $request
     * @param Visitor $visitor
     * @param Action|null $action
     * @return mixed
     */
    public function onNewVisit(Request $request, Visitor $visitor, $action)
    {
        $daysSinceLastOrder = $request->getDaysSinceLastOrder();

        if ($daysSinceLastOrder === false) {
            $daysSinceLastOrder = 0;
        }

        return $daysSinceLastOrder;
    }

    /**
     * @param Request $request
     * @param Visitor $visitor
     * @param Action|null $action
     * @return mixed
     */
    public function onAnyGoalConversion(Request $request, Visitor $visitor, $action)
    {
        return $visitor->getVisitorColumn($this->columnName);
    }
}
